𝔣𝔯𝔞𝔨𝔱𝔲𝔯
=======

𝔠𝔬𝔫𝔳𝔢𝔯𝔱 𝔱𝔥𝔢 𝔩𝔞𝔱𝔦𝔫 𝔞𝔩𝔭𝔥𝔞𝔟𝔢𝔱 𝔱𝔬 `𝔣𝔯𝔞𝔨𝔱𝔲𝔯 𝔲𝔫𝔦𝔠𝔬𝔡𝔢
𝔠𝔥𝔞𝔯𝔞𝔠𝔱𝔢𝔯𝔰 <http://www.fileformat.info/info/unicode/char/search.htm?q=fraktur&preview=entity>`__

This is heavily inspired by `substack <https://github.com/substack>`__'s
`𝔣𝔯𝔞𝔨𝔱𝔲𝔯 <https://github.com/substack/fraktur>`__

𝕴𝔫𝔰𝔱𝔞𝔩𝔩𝔞𝔱𝔦𝔬𝔫
============

To install 𝔣𝔯𝔞𝔨𝔱𝔲𝔯, simply:

::

    $ pip install fraktur

𝔘𝔰𝔞𝔤𝔢
=====

::

    import fraktur

    print fraktur.encode('Carpe Diem')
    print fraktur.decode(u'𝕮𝔞𝔯𝔭𝔢 𝔇𝔦𝔢𝔪')

Example
=======

::

    import fraktur

    quote = """So avoid using the word 'very' because it's lazy.
    A man is not very tired, he is exhausted.
    Don't use very sad, use morose.
    Language was invented for one reason,
    boys - to woo women - and, in that endeavor,
    laziness will not do. It also won't do in your essays."""

    print fraktur.encode(quote)
    print
    print fraktur.decode(fraktur.encode(quote))

.. figure:: https://raw.githubusercontent.com/carpedm20/fraktur/master/example/example.png
   :alt: example

𝔏𝔦𝔫𝔨
====

`𝔣𝔯𝔞𝔨𝔱𝔲𝔯 𝔲𝔫𝔦𝔠𝔬𝔡𝔢
𝔠𝔥𝔞𝔯𝔞𝔠𝔱𝔢𝔯𝔰 <http://www.fileformat.info/info/unicode/char/search.htm?q=fraktur&preview=entity>`__

𝔏𝔦𝔠𝔢𝔫𝔰𝔢
=======

𝔐𝕴𝔗
